#
# spec file for package nginx-1.1
#
# Copyright (c) 2011 SUSE LINUX Products GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#

Name:           nginx-1.1
Version:        1.1.19
Release:        1.19
#
%define pkg_name nginx
#
%define ngx_prefix     %{_prefix}
%define ngx_sbindir    %{_sbindir}/nginx
%define ngx_conf_dir   %{_sysconfdir}/nginx
%define ngx_conf_path  %{ngx_conf_dir}/nginx.conf
%define ngx_log_dir    /var/log/nginx
%define ngx_error_log  %{ngx_log_dir}/error.log
%define ngx_access_log %{ngx_log_dir}/access.log
%define ngx_pid_path   /var/run/nginx.pid
%define ngx_lock_path  /var/run/nginx.lock
%define ngx_home       /var/lib/nginx
%define ngx_tmp_http   %{ngx_home}/tmp/
%define ngx_tmp_proxy  %{ngx_home}/proxy/
%define ngx_tmp_fcgi   %{ngx_home}/fastcgi/
%define ngx_tmp_scgi   %{ngx_home}/scgi/
%define ngx_tmp_uwsgi  %{ngx_home}/uwsgi/
%define ngx_user_group nginx
%define with_cpp_test   0
%define with_google_perftools 0
%if 0%{?suse_version} >= 1110 && 0%{?sles_version} != 10 && 0%{?sles_version} != 11
%define with_passenger 1
%define with_libatomic 1
%endif
#
Group:          Productivity/Networking/Web/Proxy
License:        BSD-2-Clause
#
BuildRoot:      %{_tmppath}/%{name}-%{version}-build
%if 0%{?with_cpp_test}
BuildRequires:  gcc-c++
%endif
BuildRequires:  gd-devel
BuildRequires:  GeoIP-devel
%if 0%{?with_google_perftools}
BuildRequires:  google-perftools-devel
%endif
%if 0%{?with_libatomic}
BuildRequires:  libatomic-ops-devel
%endif
BuildRequires:  libxslt-devel
BuildRequires:  openssl-devel
BuildRequires:  pcre-devel
BuildRequires:  pkgconfig
BuildRequires:  zlib-devel
%if 0%{?with_passenger}
BuildRequires:  rubygem-passenger-devel-static
Recommends:     packageand(rubygem-passenger:rubygem-passenger-nginx)
%endif
PreReq:         %fillup_prereq
PreReq:         %insserv_prereq
PreReq:         pwdutils
Provides:       nginx = %{version}-%{release}
#
Conflicts:      nginx-0.5 nginx-0.6 nginx-0.7 nginx-0.8 nginx-0.9 nginx-1.0
%requires_eq    perl
#
Url:            http://nginx.org/
Source:         http://nginx.org/download/nginx-%{version}.tar.bz2
Source1:        nginx.init
# PATCH-FIX-UPSTREAM nginx-0.4.0-no_Werror.patch
Patch:          nginx-0.4.0-no_Werror.patch
# PATCH-FIX-UPSTREAM nginx-0.6.38-html.patch
Patch2:         nginx-1.0.12-html.patch
# PATCH-FIX-UPSTREAM nginx-0.4.0-perl_vendor_install.patch
Patch3:         nginx-0.4.0-perl_vendor_install.patch
# PATCH-FIX-UPSTREAM nginx-1.0.4_default_config.patch
Patch4:         nginx-1.0.4_default_config.patch
#
Summary:        A HTTP server and IMAP/POP3 proxy server
%description
nginx [engine x] is a HTTP server and IMAP/POP3 proxy server written by Igor Sysoev.
It has been running on many heavily loaded Russian sites for more than two years.

Author:
-------
    Igor Sysoev

%prep
%setup -n %{pkg_name}-%{version}
%patch
%patch3
%patch4
%patch2
perl -pi -e 's|\r\n|\n|g' contrib/geo2nginx.pl

%build
%if 0%{?with_passenger}
ln -s %{_libdir}/ruby/gems/%{rb_ver}/gems/passenger-* passenger
%endif
./configure                                    \
  --prefix=%{ngx_prefix}/                      \
  --sbin-path=%{ngx_sbindir}                   \
  --conf-path=%{ngx_conf_path}                 \
  --error-log-path=%{ngx_error_log}            \
  --http-log-path=%{ngx_access_log}            \
  --pid-path=%{ngx_pid_path}                   \
  --lock-path=%{ngx_lock_path}                 \
  --http-client-body-temp-path=%{ngx_tmp_http} \
  --http-proxy-temp-path=%{ngx_tmp_proxy}      \
  --http-fastcgi-temp-path=%{ngx_tmp_fcgi}     \
  --http-uwsgi-temp-path=%{ngx_tmp_uwsgi}      \
  --http-scgi-temp-path=%{ngx_tmp_scgi}        \
  --user=nginx --group=nginx                   \
  --with-rtsig_module                          \
  --with-select_module                         \
  --with-poll_module                           \
  --with-ipv6                                  \
%if  0%{?suse_version} > 1110
  --with-file-aio                              \
%endif
  --with-http_ssl_module                       \
  --with-http_realip_module                    \
  --with-http_addition_module                  \
  --with-http_xslt_module                      \
  --with-http_image_filter_module              \
  --with-http_geoip_module                     \
  --with-http_sub_module                       \
  --with-http_dav_module                       \
  --with-http_flv_module                       \
  --with-http_mp4_module                       \
  --with-http_gzip_static_module               \
  --with-http_random_index_module              \
  --with-http_secure_link_module               \
  --with-http_degradation_module               \
  --with-http_stub_status_module               \
  --with-http_perl_module                      \
  --with-perl=%{_bindir}/perl                  \
  --with-mail                                  \
  --with-mail_ssl_module                       \
  --with-pcre                                  \
  %if 0%{?with_libatomic}
  --with-libatomic                             \
  %endif
  %if 0%{?with_passenger}
  --add-module=passenger/ext/nginx             \
  %endif
  %if 0%{?with_google_perftools}
  --with-google_perftools_module               \
  %endif
  %if 0%{?with_cpp_test}
  --with-cpp_test_module                       \
  %endif
  --with-md5=/usr                              \
  --with-sha1=/usr                             \
%if 0%{?suse_version} > 1000 || 0%{?fedora_version} > 4 || 0%{?mandriva_version} > 2006
  --with-cc-opt="%{optflags} -fstack-protector"
%else
  --with-cc-opt="%{optflags}"
%endif
%{__make}

%install
%makeinstall
%perl_process_packlist
#
%{__install} -d -m 0750 %{buildroot}%{ngx_home}/{,tmp,proxy,fastcgi,scgi,uwsgi}
#
%{__install} -D -m 0755 %{S:1} %{buildroot}%{_sysconfdir}/init.d/%{pkg_name}
%{__ln_s} -f %{_sysconfdir}/init.d/%{pkg_name} %{buildroot}%{_sbindir}/rc%{pkg_name}
%{__rm} %{buildroot}/srv/www/htdocs/index.html

%post
%fillup_and_insserv %{pkg_name}

%preun
%stop_on_removal %{pkg_name}

%postun
%restart_on_update %{pkg_name}
%{insserv_cleanup}

%clean
%{__rm} -rf %{buildroot}

%pre
/usr/sbin/groupadd -r %{ngx_user_group} &>/dev/null ||:
/usr/sbin/useradd -g %{ngx_user_group} -s /bin/false -r -c "user for %{ngx_user_group}" -d %{ngx_home} %{ngx_user_group} &>/dev/null ||:

%files
%defattr(-,root,root,-)
%dir %{ngx_conf_dir}/
%config(noreplace) %{ngx_conf_dir}/koi-utf
%config(noreplace) %{ngx_conf_dir}/koi-win
%config(noreplace) %{ngx_conf_dir}/fastcgi_params
%config(noreplace) %{ngx_conf_dir}/fastcgi_params.default
%config(noreplace) %{ngx_conf_dir}/mime.types
%config(noreplace) %{ngx_conf_dir}/mime.types.default
%config(noreplace) %{ngx_conf_dir}/nginx.conf
%config(noreplace) %{ngx_conf_dir}/nginx.conf.default
%config(noreplace) %{ngx_conf_dir}/fastcgi.conf
%config(noreplace) %{ngx_conf_dir}/fastcgi.conf.default
%config(noreplace) %{ngx_conf_dir}/win-utf
%config(noreplace) %{ngx_conf_dir}/scgi_params
%config(noreplace) %{ngx_conf_dir}/scgi_params.default
%config(noreplace) %{ngx_conf_dir}/uwsgi_params
%config(noreplace) %{ngx_conf_dir}/uwsgi_params.default
%{perl_vendorarch}/auto/nginx/
%{perl_vendorarch}/nginx.pm
%{ngx_sbindir}
%{_mandir}/man3/nginx.3pm*
/srv/www/htdocs/50x.html
%if 0%{?suse_version} && 0%{?suse_version} < 1140
%{_localstatedir}/adm/perl-modules/%{name}
%endif
%{_sysconfdir}/init.d/%{pkg_name}
%{_sbindir}/rc%{pkg_name}
%dir %attr(750,%{ngx_user_group},%{ngx_user_group}) /var/log/nginx/
%dir %attr(750,%{ngx_user_group},%{ngx_user_group}) %{ngx_home}/
%dir %attr(750,%{ngx_user_group},%{ngx_user_group}) %{ngx_tmp_http}
%dir %attr(750,%{ngx_user_group},%{ngx_user_group}) %{ngx_tmp_proxy}
%dir %attr(750,%{ngx_user_group},%{ngx_user_group}) %{ngx_tmp_fcgi}
%dir %attr(750,%{ngx_user_group},%{ngx_user_group}) %{ngx_tmp_scgi}
%dir %attr(750,%{ngx_user_group},%{ngx_user_group}) %{ngx_tmp_uwsgi}
%doc CHANGES* LICENSE README
%doc conf/ contrib/

%changelog
* Sat May  5 2012 cs@linux-administrator.com
- upstream update 1.1.19
  * Security: specially crafted mp4 file might allow to overwrite memory
    locations in a worker process if the ngx_http_mp4_module was used,
    potentially resulting in arbitrary code execution (CVE-2012-2089).
  * Bugfix: in the ngx_http_mp4_module.
* Sun Apr  8 2012 cs@linux-administrator.com
- upstream update 1.1.18
  * Change: keepalive connections are no longer disabled for Safari by
    default.
  * Feature: the $connection_requests variable.
  * Feature: $tcpinfo_rtt, $tcpinfo_rttvar, $tcpinfo_snd_cwnd and
    $tcpinfo_rcv_space variables.
  * Feature: the "worker_cpu_affinity" directive now works on FreeBSD.
  * Feature: the "xslt_param" and "xslt_string_param" directives.
  * Bugfix: in configure tests.
  * Bugfix: in the ngx_http_xslt_filter_module.
  * Bugfix: nginx could not be built on Debian GNU/Hurd.
* Tue Mar 20 2012 cs@linux-administrator.com
- upstream update 1.1.17
  * Security: content of previously freed memory might be sent to a
    client if backend returned specially crafted response.
    Thanks to Matthew Daley.
  * Bugfix: in the embedded perl module if used from SSI.
  * Bugfix: in the ngx_http_uwsgi_module.
- additional changes from 1.1.16
  * Change: the simultaneous subrequest limit has been raised to 200.
  * Feature: the "from" parameter of the "disable_symlinks" directive.
  * Feature: the "return" and "error_page" directives can now be used to
    return 307 redirections.
  * Bugfix: a segmentation fault might occur in a worker process if the
    "resolver" directive was used and there was no "error_log" directive
    specified at global level.
  * Bugfix: a segmentation fault might occur in a worker process if the
    "proxy_http_version 1.1" or "fastcgi_keep_conn on" directives were
    used.
  * Bugfix: memory leaks.
  * Bugfix: in the "disable_symlinks" directive.
  * Bugfix: on ZFS filesystem disk cache size might be calculated
    incorrectly; the bug had appeared in 1.0.1.
  * Bugfix: nginx could not be built by the icc 12.1 compiler.
  * Bugfix: nginx could not be built by gcc on Solaris; the bug had
    appeared in 1.1.15.
